==> haskell-djinn-lib-0.0.1.3-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-djinn-lib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: djinn-lib
version: 0.0.1.3
id: djinn-lib-0.0.1.3-JjfOG3wSqQ42UziBnp4wOB
key: djinn-lib-0.0.1.3-JjfOG3wSqQ42UziBnp4wOB
license: BSD-3-Clause
maintainer: trupill@gmail.com
author: Lennart Augustsson
homepage: http://www.augustsson.net/Darcs/Djinn/
synopsis: Generate Haskell code from a type. Library extracted from djinn package.
description:
    Djinn uses an theorem prover for intuitionistic propositional logic
    to generate a Haskell expression when given a type.
    This is a library extracted from Djinn sources.
category: Language
abi: ba500f02ab2e87e4b2ea05cb1aff6455
exposed: True
exposed-modules:
    Djinn.HCheck Djinn.HTypes Djinn.LJT Djinn.LJTFormula
import-dirs: /usr/lib/ghc-8.4.3/site-local/djinn-lib-0.0.1.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/djinn-lib-0.0.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/djinn-lib-0.0.1.3
hs-libraries: HSdjinn-lib-0.0.1.3-JjfOG3wSqQ42UziBnp4wOB
depends:
    base-4.11.1.0 containers-0.5.11.0 mtl-2.2.2 pretty-1.1.3.6
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             pretty-1.1.3.6=242598bba36778e604a1e89d5c7ce1a8
haddock-interfaces: /usr/share/doc/haskell-djinn-lib/html/djinn-lib.haddock
haddock-html: /usr/share/doc/haskell-djinn-lib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-djinn-lib-0.0.1.3-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-djinn-lib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: djinn-lib
version: 0.0.1.3
id: djinn-lib-0.0.1.3-IYL2QiLeEeMIQ004pufpeW
key: djinn-lib-0.0.1.3-IYL2QiLeEeMIQ004pufpeW
license: BSD-3-Clause
maintainer: trupill@gmail.com
author: Lennart Augustsson
homepage: http://www.augustsson.net/Darcs/Djinn/
synopsis: Generate Haskell code from a type. Library extracted from djinn package.
description:
    Djinn uses an theorem prover for intuitionistic propositional logic
    to generate a Haskell expression when given a type.
    This is a library extracted from Djinn sources.
category: Language
abi: c0cad376b03056daa5e8609834cc7f55
exposed: True
exposed-modules:
    Djinn.HCheck Djinn.HTypes Djinn.LJT Djinn.LJTFormula
import-dirs: /usr/lib/ghc-8.6.1/site-local/djinn-lib-0.0.1.3
library-dirs: /usr/lib/ghc-8.6.1/site-local/djinn-lib-0.0.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/djinn-lib-0.0.1.3
hs-libraries: HSdjinn-lib-0.0.1.3-IYL2QiLeEeMIQ004pufpeW
depends:
    base-4.12.0.0 containers-0.6.0.1 mtl-2.2.2 pretty-1.1.3.6
haddock-interfaces: /usr/share/doc/haskell-djinn-lib/html/djinn-lib.haddock
haddock-html: /usr/share/doc/haskell-djinn-lib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
